"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Verbosity = void 0;
var Verbosity;
(function (Verbosity) {
    Verbosity[Verbosity["ERROR"] = 0] = "ERROR";
    Verbosity[Verbosity["WARN"] = 1] = "WARN";
    Verbosity[Verbosity["INFO"] = 2] = "INFO";
    Verbosity[Verbosity["DEBUG"] = 3] = "DEBUG";
    Verbosity[Verbosity["TRACE"] = 4] = "TRACE";
})(Verbosity = exports.Verbosity || (exports.Verbosity = {}));
let prefix = () => "";
let level = Verbosity.ERROR;
const setPrefix = (func) => {
    if (typeof func !== "function") {
        throw new Error("Prefix must be a function");
    }
    prefix = func;
};
const setVerbosity = (verbosityLevel) => {
    level = verbosityLevel;
};
const error = (...args) => {
    if (level >= Verbosity.ERROR) {
        console.error(prefix(), ...args);
    }
};
const warn = (...args) => {
    if (level >= Verbosity.WARN) {
        console.warn(prefix(), ...args);
    }
};
const info = (...args) => {
    if (level >= Verbosity.INFO) {
        console.info(prefix(), ...args);
    }
};
const debug = (...args) => {
    if (level >= Verbosity.DEBUG) {
        console.debug(prefix(), ...args);
    }
};
const trace = (...args) => {
    if (level >= Verbosity.TRACE) {
        console.trace(prefix(), ...args);
    }
};
exports.default = {
    setPrefix,
    setVerbosity,
    error,
    warn,
    info,
    debug,
    trace
};
//# sourceMappingURL=logger.js.map